package VMOMI::IoFilterOperation;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
